##########################################
Keysight E3631A Triple Output Power Supply
##########################################

.. autoclass:: pymeasure.instruments.keysight.KeysightE3631A
    :members:
    :show-inheritance:
    :inherited-members:

.. autoclass:: pymeasure.instruments.keysight.keysightE3631A.VoltageChannel
    :members:
    :show-inheritance:
